CompositeFilter class

Chains multiple string filters together.

Implemented types

Constructors

CompositeFilter(List<StringFilter> filters)

Properties

filters List<StringFilter>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(String value) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited