HumanDateFormat class
Preset formats inspired by Luxon.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- DATE_FULL → const HumanDateFormat
- DATE_MED → const HumanDateFormat
- DATE_SHORT → const HumanDateFormat
- DATETIME_FULL → const HumanDateFormat
- TIME_SIMPLE → const HumanDateFormat
- TIME_WITH_SECONDS → const HumanDateFormat