LocalizedDateTime class

Constructors

LocalizedDateTime(DateTime dt, DateTimeLocale locale, String _code)
const

Properties

dt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
locale DateTimeLocale
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHTTP() String
toISO() String
toISODate() String
toISOTime() String
toISOWeekDate() String
toLocaleString([Object? format]) String
toMillis() int
toRFC2822() String
toSeconds() double
toString() String
A string representation of this object.
inherited
toUnixInteger() int
valueOf() int

Operators

operator ==(Object other) bool
The equality operator.
inherited