SimpleLocale class

Minimal locale utilities for natural text.

Constructors

SimpleLocale({required String code, required String andWord, String decimalSeparator = '.', String thousandSeparator = ','})
const

Properties

andWord String
final
code String
final
decimalSeparator String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thousandSeparator String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

en → const SimpleLocale
fr → const SimpleLocale