HumanizeI18n class

Thin, locale-aware facade over humanize helpers.

Constructors

HumanizeI18n([String locale = 'en'])
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
locale → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

apNumber(int n) → String
capFirst(String s) → String
fileSize(num bytes, {int precision = 1}) → String
intComma(num value, {String? sep}) → String
intWord(num n, {int precision = 1, bool short = false}) → String
naturalDay(DateTime day, {DateTime? now, String format = 'yyyy-MM-dd'}) → String
naturalDelta(Duration delta) → String
naturalJoin(List<String> items, {String delimiter = ', '}) → String
naturalTime(DateTime moment, {DateTime? now}) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ordinal(int n) → String
oxford(List<String> items) → String
titleCase(String s) → String
toString() → String
A string representation of this object.
inherited
truncateChars(String s, int max, {String ellipsis = '...'}) → String
truncateWords(String s, int maxWords, {String ellipsis = '...'}) → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited